==> gnutls-0.3.92.tar.gz: gnutls-0.3.92/lib/gnutls_asn1_tab.c <==

#include "x509_asn1.h"

const static_asn gnutls_asn1_tab[]={
  {"GNUTLS",536872976,0},
  {0,1073741836,0},
  {"RSAPublicKey",1610612741,0},
  {"modulus",1073741827,0},
  {"publicExponent",3,0},
  {"RSAPrivateKey",1610612741,0},
  {"version",1073741826,"Version"},
  {"modulus",1073741827,0},
  {"publicExponent",1073741827,0},
  {"privateExponent",1073741827,0},
  {"prime1",1073741827,0},
  {"prime2",1073741827,0},
  {"exponent1",1073741827,0},
  {"exponent2",1073741827,0},
  {"coefficient",1073741827,0},
  {"otherPrimeInfos",16386,"OtherPrimeInfos"},
  {"Version",1610874883,0},
  {"two-prime",1073741825,"0"},
  {"multi",1,"1"},
  {"OtherPrimeInfos",1612709899,0},
  {"MAX",1074266122,"1"},
  {0,2,"OtherPrimeInfo"},
  {"OtherPrimeInfo",1610612741,0},
  {"prime",1073741827,0},
  {"exponent",1073741827,0},
  {"coefficient",3,0},
  {"AlgorithmIdentifier",1610612741,0},
  {"algorithm",1073741836,0},
  {"parameters",541081613,0},
  {"algorithm",1,0},
  {"DigestInfo",1610612741,0},
  {"digestAlgorithm",1073741826,"DigestAlgorithmIdentifier"},
  {"digest",2,"Digest"},
  {"DigestAlgorithmIdentifier",1073741826,"AlgorithmIdentifier"},
  {"Digest",1073741831,0},
  {"DSAPublicKey",1073741827,0},
  {"DSAParameters",1610612741,0},
  {"p",1073741827,0},
  {"q",1073741827,0},
  {"g",3,0},
  {"DSASignatureValue",1610612741,0},
  {"r",1073741827,0},
  {"s",3,0},
  {"DSAPrivateKey",536870917,0},
  {"version",1073741827,0},
  {"p",1073741827,0},
  {"q",1073741827,0},
  {"g",1073741827,0},
  {"Y",1073741827,0},
  {"priv",3,0},
  {0,0,0}
};

==> gnutls-0.8.12.tar.gz: gnutls-0.8.12/lib/gnutls_asn1_tab.c <==

#include "libtasn1.h"

const ASN1_ARRAY_TYPE gnutls_asn1_tab[]={
  {"GNUTLS",536872976,0},
  {0,1073741836,0},
  {"RSAPublicKey",1610612741,0},
  {"modulus",1073741827,0},
  {"publicExponent",3,0},
  {"RSAPrivateKey",1610612741,0},
  {"version",1073741826,"Version"},
  {"modulus",1073741827,0},
  {"publicExponent",1073741827,0},
  {"privateExponent",1073741827,0},
  {"prime1",1073741827,0},
  {"prime2",1073741827,0},
  {"exponent1",1073741827,0},
  {"exponent2",1073741827,0},
  {"coefficient",1073741827,0},
  {"otherPrimeInfos",16386,"OtherPrimeInfos"},
  {"Version",1610874883,0},
  {"two-prime",1073741825,"0"},
  {"multi",1,"1"},
  {"OtherPrimeInfos",1612709899,0},
  {"MAX",1074266122,"1"},
  {0,2,"OtherPrimeInfo"},
  {"OtherPrimeInfo",1610612741,0},
  {"prime",1073741827,0},
  {"exponent",1073741827,0},
  {"coefficient",3,0},
  {"AlgorithmIdentifier",1610612741,0},
  {"algorithm",1073741836,0},
  {"parameters",541081613,0},
  {"algorithm",1,0},
  {"DigestInfo",1610612741,0},
  {"digestAlgorithm",1073741826,"DigestAlgorithmIdentifier"},
  {"digest",2,"Digest"},
  {"DigestAlgorithmIdentifier",1073741826,"AlgorithmIdentifier"},
  {"Digest",1073741831,0},
  {"DSAPublicKey",1073741827,0},
  {"DSAParameters",1610612741,0},
  {"p",1073741827,0},
  {"q",1073741827,0},
  {"g",3,0},
  {"DSASignatureValue",1610612741,0},
  {"r",1073741827,0},
  {"s",3,0},
  {"DSAPrivateKey",536870917,0},
  {"version",1073741827,0},
  {"p",1073741827,0},
  {"q",1073741827,0},
  {"g",1073741827,0},
  {"Y",1073741827,0},
  {"priv",3,0},
  {0,0,0}
};
